Index — Orange3 Image Analytics documentation

# Index

C | F | I | M | P | S

## C

clear_cache() (orangecontrib.imageanalytics.image_embedder.ImageEmbedder method) | construct_output_data_table() (orangecontrib.imageanalytics.image_embedder.ImageEmbedder static method)

## F

from_table() (orangecontrib.imageanalytics.image_embedder.ImageEmbedder method)

## I

ImageEmbedder (class in orangecontrib.imageanalytics.image_embedder) | is_local_embedder() (orangecontrib.imageanalytics.image_embedder.ImageEmbedder method)

## M

model (orangecontrib.imageanalytics.image_embedder.ImageEmbedder attribute)

## P

prepare_output_data() (orangecontrib.imageanalytics.image_embedder.ImageEmbedder static method)

## S

server_url (orangecontrib.imageanalytics.image_embedder.ImageEmbedder attribute)